!*****************************************************************************
!                   Time-stamp: <2014-06-26 11:42:28 sander>
!      Author: Rolf Sander, Max-Planck Institute Mainz, Germany 1996-2014
!*****************************************************************************

! This program is free software; you can redistribute it and/or
! modify it under the terms of the GNU General Public License
! as published by the Free Software Foundation; either version 2
! of the License, or (at your option) any later version.
! This program is distributed in the hope that it will be useful,
! but WITHOUT ANY WARRANTY; without even the implied warranty of
! MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
! GNU General Public License for more details.
! You should have received a copy of the GNU General Public License
! along with this program; if not, get it from:
! http://www.gnu.org/copyleft/gpl.html

!*****************************************************************************

MODULE henry_ref3500

  USE henry_mem
  USE henry_util
  IMPLICIT NONE

CONTAINS

  !---------------------------------------------------------------------------

  SUBROUTINE ref3003 ! Hcp [M/atm]
    IMPLICIT NONE

    ref = "3003"
    type = "M"

    chem = "ammonia" ; casrn = "7664-41-7" ! NH3
    mindHR = 3214.4
    Hominus = EXP(-7.44+mindHR/T0)*Hcp_TO_HcpSI
    CALL Output(Hominus,mindHR)

  END SUBROUTINE ref3003

  !---------------------------------------------------------------------------

  SUBROUTINE ref3005 ! kHpx [kPa]
    IMPLICIT NONE
    REAL :: kH_kPa
    chem = "ozone" ; casrn = "10028-15-6" ! O3
    ref = "3005"
    type = "M"
    mindHR = 1364.5
    kH_kPa = 4.67E7*EXP(-mindHR/T0)
    Hominus = cH2O/(1E3*kH_kPa)
    CALL Output(Hominus,mindHR)
  END SUBROUTINE ref3005

  !---------------------------------------------------------------------------

  SUBROUTINE ref3006 ! kHpx [kPa], kHcc [1]
    IMPLICIT NONE

    ref = "3006"
    type = "V"
    ndata = 5
    ALLOCATE(temp(ndata), Harray(ndata))
    temp = (/ 298.15, 308.15, 318.15, 328.15, 338.15 /)
    CALL CalcH_Tdep( "fluoranthene",   "206-44-0", &
      (/ 29.9,   68.3,  193.,  425.,  911. /), (/ 21.7,   48.0,   131.,  280.,  583. /))
    CALL CalcH_Tdep( "1,2,3,4-dibenzantheracene DBA(a,c)",   "215-58-7", &
      (/ 2.61,   7.17,  23.9,  45.7,  71.7 /), (/ 1.89,   5.04,   16.3,  30.1,  45.9 /))
    CALL CalcH_Tdep( "1,2,5,6-dibenzantheracene DBA(a,h)",   "53-70-3", &
      (/ 0.297,  1.22,  3.37,  12.2,  32.3 /), (/ 0.216,  0.858,  2.30,  8.06,  20.7 /))
    DEALLOCATE(temp, Harray)

CONTAINS

    SUBROUTINE CalcH_Tdep (chem_, casrn_, kHpx, Kaw)

      IMPLICIT NONE
      CHARACTER(LEN=*),   INTENT(IN) :: chem_
      CHARACTER(LEN=*),   INTENT(IN) :: casrn_
      REAL, DIMENSION(:), INTENT(IN) :: kHpx, Kaw
      REAL :: Hominus_from_kHpx, mindHR_from_kHpx
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it

      Harray = kHcc_TO_HcpSI(1E-5*Kaw,temp)
      CALL HTdep(temp, Harray, Hominus, mindHR)
      CALL Output(Hominus, mindHR, r2)

      ! compare to Kaw values from the same table:
      Harray = cH2O/(1E3*kHpx)
      CALL HTdep(temp, Harray, Hominus_from_kHpx, mindHR_from_kHpx)
      CALL consistency_check(Hominus_from_kHpx, Hominus, &
        "Hominus Values in Table 11")
      CALL consistency_check(mindHR_from_kHpx, mindHR, &
        "mindHR Values in Table 11")

    END SUBROUTINE CalcH_Tdep

  END SUBROUTINE ref3006

  !---------------------------------------------------------------------------

  SUBROUTINE ref3007 ! Hcp [M/atm]
    IMPLICIT NONE

    ref = "3007"
    type = "M"

    chem = "methylbenzene" ; casrn = "108-88-3" ! C6H5CH3 toluene
    CALL Output(0.157*Hcp_TO_HcpSI)

    chem = "2-butanamine" ; casrn = "13952-84-6" ! C4H{11}N
    CALL MakeNote(TRIM(ref), "In their Fig.~5b, "//TRIM(citet())// &
      " apply an unspecified factor to the Henry's law constant, " // &
      "and it is not clear if the temperature dependence shown " // &
      "there is correct (Liu, pers.\ comm.\ 2014).")
    CALL Output(40.7*Hcp_TO_HcpSI, 7657.)

    chem = "cineole" ; casrn = "470-82-6" ! 1,8-cineole
    CALL Output(6.0*Hcp_TO_HcpSI)

  END SUBROUTINE ref3007

  !---------------------------------------------------------------------------

  SUBROUTINE ref3008 ! Hcp [M/atm]
    IMPLICIT NONE

    ref = "3008"
    type = "M"
    ndata = 5
    ALLOCATE(temp(ndata))
    temp = (/ 298., 293., 288., 283., 278. /)
    CALL CalcH("isoprene",      "78-79-5", (/ 0.036, 0.044, 0.056, 0.079, 0.100 /)) ! C_5H_8
    CALL CalcH("limonene",     "138-86-3", (/ 0.048, 0.066, 0.083, 0.112, 0.147 /)) ! C_{10}H_{16}
    CALL CalcH("alpha-pinene",  "80-56-8", (/ 0.029, 0.034, 0.036, 0.042, 0.045 /)) ! C_{10}H_{16}
    CALL CalcH("linalool",      "78-70-6", (/ 21.20, 25.97, 33.63, 43.22, 62.08 /)) ! C_{10}H_{18}O
    DEALLOCATE(temp)

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, Harray)
      IMPLICIT NONE
      CHARACTER(LEN=*),   INTENT(IN) :: chem_
      CHARACTER(LEN=*),   INTENT(IN) :: casrn_
      REAL, DIMENSION(:), INTENT(IN) :: Harray
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      CALL HTdep(temp, Harray*Hcp_TO_HcpSI, Hominus, mindHR)
      CALL Output(Hominus, mindHR, r2)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3008

  !---------------------------------------------------------------------------

  SUBROUTINE ref3009 ! kHpcSI [Pa*m3/mol]
    IMPLICIT NONE

    ref = "3009"
    type = "M"
    ! Tab. 2:
    CALL CalcH("1,2,4,5-tetrachlorobenzene",  "95-94-3", 57.) ! C6H2Cl4
    CALL CalcH("pentachlorobenzene",         "608-93-5", 33.) ! C6HCl5
    CALL CalcH("hexachlorobenzene",          "118-74-1", 30.) ! C6Cl6

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, H)
      IMPLICIT NONE
      CHARACTER(LEN=*), INTENT(IN) :: chem_
      CHARACTER(LEN=*), INTENT(IN) :: casrn_
      REAL,             INTENT(IN) :: H
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      CALL Output(kHpcSI_TIMES_HcpSI/H)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3009

  !---------------------------------------------------------------------------

  SUBROUTINE ref3013 ! kHpcSI [Pa*m3/mol]
    IMPLICIT NONE

    ref = "3013"

    ! Tab. 2:
    type = "M"
    CALL CalcH_Tdep("4-2FTOH",  "2043-47-2", &
      (/ 309.6, 314.5, 319.6, 323., 330., 334.2 /), &
      (/ 283., 314., 399., 483., 631., 806. /), &
      (/ 2.45, 2.50, 2.60, 2.68, 2.80, 2.91 /))
    CALL CalcH_Tdep("6-2FTOH",   "647-42-7", &
      (/ 309.6, 314.5, 319.6, 323., 330., 334.2 /), &
      (/ 7259., 9413., 10894., 11467., 12456., 14309. /), &
      (/ 3.86, 3.97, 4.04, 4.06, 4.10, 4.16 /))
    CALL CalcH_Tdep("8-2FTOH",   "678-39-7", &
      (/ 309.6, 314.5, 319.6, 323. /), &
      (/ 7593., 8550., 10257., 11520. /), &
      (/ 3.88, 3.93, 4.01, 4.06 /))
    CALL CalcH_Tdep("10-2FTOH",  "865-86-1", &
      (/ 309.6, 314.5, 319.6, 323., 330., 334.2 /), &
      (/ 9987., 12943., 15119., 16193., 18245., 19589. /), &
      (/ 4.00, 4.11, 4.18, 4.21, 4.26, 4.29 /))

    ! Tab. 4:
    type = "V"
    CALL CalcH("4-2FTOH",  "2043-47-2", 1.77)
    CALL CalcH("6-2FTOH",   "647-42-7", 2.54)
    CALL CalcH("8-2FTOH",   "678-39-7", 4.10)
    CALL CalcH("10-2FTOH",  "865-86-1", 4.01)

CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, KH)
      IMPLICIT NONE
      CHARACTER(LEN=*), INTENT(IN) :: chem_
      CHARACTER(LEN=*), INTENT(IN) :: casrn_
      REAL,             INTENT(IN) :: KH
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      CALL Output(kHpcSI_TIMES_HcpSI/KH)
    END SUBROUTINE CalcH

    SUBROUTINE CalcH_Tdep (chem_, casrn_, temp, KH, logKH)

      IMPLICIT NONE
      CHARACTER(LEN=*),   INTENT(IN) :: chem_
      CHARACTER(LEN=*),   INTENT(IN) :: casrn_
      REAL, DIMENSION(:), INTENT(IN) :: temp, KH, logKH
      REAL :: Hominus_from_logKH, mindHR_from_logKH
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it

      CALL HTdep(temp, kHpcSI_TIMES_HcpSI/KH, Hominus, mindHR)
      CALL Output(Hominus, mindHR, r2)

      ! compare to log(KH) values from the same Table:
      CALL HTdep(temp, kHpcSI_TIMES_HcpSI/(10.**logKH), Hominus_from_logKH, mindHR_from_logKH)
      CALL consistency_check(Hominus_from_logKH, Hominus, &
        "Hominus Values in Table 2")
      CALL consistency_check(mindHR_from_logKH, mindHR, &
        "mindHR Values in Table 2")

    END SUBROUTINE CalcH_Tdep

  END SUBROUTINE ref3013

  !---------------------------------------------------------------------------

  SUBROUTINE ref3014 ! kHpcSI [Pa*m3/mol]
    IMPLICIT NONE

    ref = "3014"
    type = "M"
    ! Tab. 2:
    CALL CalcH("naphthalene",                 "91-20-3", 16.7    ) ! C{10}H8 
    CALL CalcH("acenaphthene",                "83-32-9", 3.84    ) ! C{12}H{10} 
    CALL CalcH("2,3-benzindene",              "86-73-7", 3.12    ) ! C{13}H{10} fluorene
    CALL CalcH("phenanthrene",                "85-01-8", 5.61    ) ! C{14}H{10} 
    CALL CalcH("anthracene",                 "120-12-7", 6.33    ) ! C{14}H{10} 
    CALL CalcH("benzo[$jk$]fluorene",        "206-44-0", 2.98    ) ! C{16}H{10} fluoranthene
    CALL CalcH("pyrene",                     "129-00-0", 2.44    ) ! C{16}H{10} 
    CALL CalcH("benz[$a$]anthracene",         "56-55-3", 0.600   ) ! C{18}H{12} 
    CALL CalcH("chrysene",                   "218-01-9", 0.478   ) ! C{18}H{12} 
    CALL CalcH("benzo[$k$]fluoranthene",     "207-08-9", 0.0958  ) ! C{20}H{12} 
    CALL CalcH("benzo[$a$]pyrene",            "50-32-8", 0.161   ) ! C{20}H{12} benz[$a$]pyrene
    CALL CalcH("1,2,3-trichlorobenzene",      "87-61-6", 125.    ) ! C6H3Cl3 
    CALL CalcH("1,2,4-trichlorobenzene",     "120-82-1", 171.    ) ! C6H3Cl3 
    CALL CalcH("1,2,4,5-tetrachlorobenzene",  "95-94-3", 152.    ) ! C6H2Cl4 
    CALL CalcH("pentachlorobenzene",         "608-93-5", 179.    ) ! C6HCl5 
    CALL CalcH("hexachlorobenzene",          "118-74-1", 132.    ) ! C6Cl6 
    CALL CalcH("dibutyl phthalate",           "84-74-2", 0.108   ) ! C{16}H{22}O4 
    CALL CalcH("butyl benzyl phthalate",      "85-68-7", 0.00969 ) ! C{19}H{20}O4 
    CALL CalcH("musk xylene",                 "81-15-2", 3.11    ) ! C{12}H{15}N3O6 musk xylol
    CALL CalcH("musk ketone",                 "81-14-1", 0.336   ) ! C{14}H{18}N2O5 

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, H)
      IMPLICIT NONE
      CHARACTER(LEN=*), INTENT(IN) :: chem_
      CHARACTER(LEN=*), INTENT(IN) :: casrn_
      REAL,             INTENT(IN) :: H
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      CALL Output(kHpcSI_TIMES_HcpSI/H)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3014

  !---------------------------------------------------------------------------

  SUBROUTINE ref3015 ! kHpx [MPa]
    IMPLICIT NONE

    ref = "3015"
    type = "M"
    chem = "silicic acid" ; casrn = "10193-36-9" ! Si(OH)4
    ! Tab. 2:
    ndata = 23
    ALLOCATE(temp(ndata), Harray(ndata))
    temp = (/ 273.15, 298.15, 323.15, 348.15, 373.15, 398.15, 423.15, 448.15, 473.15, &
      498.15, 523.15, 548.15, 573.15, 598.15, 623.15, 628.15, 633.15, 638.15, &
      643.15, 644.15, 645.15, 646.15, 647.096 /)
    Harray = 1E-6 * cH2O / EXP( (/ -31.185, -26.803, -23.104, -19.970, -17.294, -14.991, -12.993, &
      -11.247, -9.709, -8.342, -7.117, -6.006, -4.979, -3.999, -2.991, &
      -2.767, -2.523, -2.245, -1.896, -1.803, -1.689, -1.532, -1.054 /) )
    CALL HTdep(temp, Harray, Hominus, mindHR)
    CALL MakeNote(TRIM(ref), "Extrapolated from data at elevated temperatures.")
    CALL Output(Hominus, mindHR, r2)
    DEALLOCATE(temp, Harray)

  END SUBROUTINE ref3015

  !---------------------------------------------------------------------------

  SUBROUTINE ref3022 ! Hcp [M/atm]
    IMPLICIT NONE

    ref = "3022"
    type = "V"

    CALL CalcH("oxalic acid",    "144-62-7", 6.2E8        )
    CALL CalcH("malonic acid",   "141-82-2", 3.9E10,  92. )
    CALL CalcH("malonic acid",   "141-82-2", 9.4E9,  113. )
    CALL CalcH("succinic acid",  "110-15-6", 4.2E9,   94. )
    CALL CalcH("succinic acid",  "110-15-6", 2.0E9,   97. )
    CALL CalcH("glutaric acid",  "110-94-1", 5.2E9,   97. )
    CALL CalcH("glutaric acid",  "110-94-1", 2.4E9,  109. )
    CALL CalcH("adipic acid",    "124-04-9", 6.7E9,  105. )
    CALL CalcH("pimelic acid",   "111-16-0", 8.2E9,  121. )
    CALL CalcH("suberic acid",   "505-48-6", 7.8E9,  120. )
    CALL CalcH("azelaic acid",   "123-99-9", 9.0E9,  140. )
    CALL CalcH("sebacic acid",   "111-20-6", 7.7E9        )
    CALL CalcH("malic acid",    "6915-15-7", 2.7E10       )
    CALL CalcH("tartaric acid",   "87-69-4", &
      range=TRIM(H_range(7E16*Hcp_TO_HcpSI,93E16*Hcp_TO_HcpSI)))
    CALL CalcH("citric acid",     "77-92-9", &
      range=TRIM(H_range(2E16*Hcp_TO_HcpSI,60E16*Hcp_TO_HcpSI)))

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, H, minDHg, range)
      IMPLICIT NONE
      CHARACTER(LEN=*),             INTENT(IN) :: chem_
      CHARACTER(LEN=*),             INTENT(IN) :: casrn_
      REAL,             OPTIONAL,   INTENT(IN) :: H
      REAL,             OPTIONAL,   INTENT(IN) :: minDHg ! minus Delta Hg
      CHARACTER(LEN=*), OPTIONAL,   INTENT(IN) :: range
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      IF (PRESENT(range)) THEN
        CALL MakeNote(TRIM(ref)//"-"//casrn_//"-range", &
          TRIM(citet())//" recommend $\Hsymbol$ for "//chem_//" in the range of "//range//".")
      ENDIF
      IF (PRESENT(H)) THEN
        Hominus = Hcp_TO_HcpSI * H
        IF (PRESENT(minDHg)) THEN
          CALL Output(Hominus, 1E3*minDHg/Rgas)
        ELSE
          CALL Output(Hominus)
        ENDIF
      ELSE
        CALL Output(DUMMY)
      ENDIF

    END SUBROUTINE CalcH

  END SUBROUTINE ref3022

  !---------------------------------------------------------------------------

  SUBROUTINE ref3024 ! kHpcSI [Pa*m3/mol]
    IMPLICIT NONE

    ref = "3024"
    type = "V"
    ! Tab. 4:
    CALL CalcH("BDE-47",            "5436-43-1", 1.08    ) ! C{12}H6Br4O 
    CALL CalcH("BDE-99",           "60348-60-9", 4.74e-1 ) ! C{12}H5Br5O 
    CALL CalcH("BDE-153",          "68631-49-2", 1.63e-1 ) ! C{12}H4Br6O 
    CALL CalcH("hexabromobenzene",    "87-82-1", 2.43    ) ! C6Br6 
    CALL CalcH("BTBPE",            "37853-59-1", 5.56e-2 ) ! C{14}H8Br6O2 

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, H)
      IMPLICIT NONE
      CHARACTER(LEN=*), INTENT(IN) :: chem_
      CHARACTER(LEN=*), INTENT(IN) :: casrn_
      REAL,             INTENT(IN) :: H
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      CALL Output(kHpcSI_TIMES_HcpSI/H)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3024

  !---------------------------------------------------------------------------

  SUBROUTINE ref3025 ! kHpc [atm*m3/mol]
    IMPLICIT NONE

    ref = "3025"
    type = "Q"

    CALL CalcH("ethyl butanoate", "105-54-4", 0.00041) ! C3H7COOC2H5 ethyl butyrate
    CALL CalcH("ethyl hexanoate", "123-66-0", 0.00072) ! C5H{11}COOC2H5 
    CALL CalcH("ethyl octanoate", "106-32-1", 0.00127) ! C7H{15}COOC2H5 
    CALL CalcH("cumene",           "98-82-8", 0.01050) ! C6H5C3H7 isopropylbenzene
    CALL CalcH("1-octanol",       "111-87-5", 0.00003) ! C8H{18}O 
    CALL CalcH("linalool",         "78-70-6", 0.00004) ! C{10}H{18}O 

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, H)
      IMPLICIT NONE
      CHARACTER(LEN=*), INTENT(IN) :: chem_
      CHARACTER(LEN=*), INTENT(IN) :: casrn_
      REAL,             INTENT(IN) :: H
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      Hominus = 1. / (atm*H)
      CALL Output(Hominus)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3025

  !---------------------------------------------------------------------------

  SUBROUTINE ref3026 ! Bunsen coefficient alpha [1]
    IMPLICIT NONE

    ref = "3026"
    type = "M"

    CALL CalcH("hydrogen", "1333-74-0", (/ 0.50, 0.58, 0.62, 10.07, &   
      9.85, 10.00, 20.00, 20.03, 20.00, 30.01, 30.00, 29.98, 30.00, 30.00, &  
      30.00, 39.96, 39.89, 39.88, 40.00, 40.00, 40.00, 50.02, 49.85, 49.98, &
      50.10, 50.03, 49.90/), &
      (/ 0.02141, 0.02134, 0.02132, 0.01956, 0.01961, 0.01948, 0.01828, &
      0.01815, 0.01815, 0.01692, 0.01696, 0.01671, 0.01712, 0.01714, &
      0.01706, 0.01649, 0.01639, 0.01636, 0.01644, 0.01645, 0.01648, &
      0.01603, 0.01609, 0.01609, 0.01616, 0.01607, 0.01606 /) ) ! H2

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, temp_, alpha)
      IMPLICIT NONE
      CHARACTER(LEN=*),   INTENT(IN) :: chem_
      CHARACTER(LEN=*),   INTENT(IN) :: casrn_
      REAL, DIMENSION(:), INTENT(IN) :: temp_, alpha
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      ndata = SIZE(alpha)
      ALLOCATE(Harray(ndata))
      Harray = alpha * alpha_TO_HcpSI
      CALL HTdep(temp_+CtoK, Harray, Hominus, mindHR)
      CALL Output(Hominus, mindHR, r2)
      DEALLOCATE(Harray)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3026

  !---------------------------------------------------------------------------

  SUBROUTINE ref3027 ! Bunsen coefficient alpha [1]
    IMPLICIT NONE

    ! The absorption coefficient beta is not defined in this paper but
    ! it is assumed that it has the same definition as in ref3026.

    ref = "3027"
    type = "M"

    CALL CalcH("nitrogen", "7727-37-9", (/ 0.09, 0.12, 0.10, 0.07, 0.05, &
      0.07, 10.02, 9.97, 10.00, 10.00, 10.05, 20.04, 20.02, 19.99, 19.93, &
      20.05, 20.05, 20.00, 20.00, 30.00, 29.95, 29.93, 30.01, 30.00, 29.93, &
      39.94, 39.92, 40.04, 40.01, 40.05, 40.05, 50.00, 50.03, 49.88, 50.07, &
      49.97, 50.05 /), &
      ! high-temperature data not used: 60.08, 60.05, 60.00, 60.01,
      ! 59.96, 70.05, 70.01, 69.90, 80.03, 80.07, 79.88, 79.95, 80.04
      (/ 0.02340, 0.02342, 0.02342, 0.02345, 0.02345, 0.02347, 0.01854, &
      0.01852, 0.01860, 0.01860, 0.01856, 0.01540, 0.01545, 0.01542, &
      0.01536, 0.01546, 0.01544, 0.01521, 0.01542, 0.01345, 0.01341, &
      0.01341, 0.01341, 0.01334, 0.01338, 0.01180, 0.01182, 0.01182, &
      0.01185, 0.01184, 0.01182, 0.01084, 0.01088, 0.01076, 0.01089, &
      0.01087, 0.01096 /) ) ! N2
      ! high-temperature data not used: 0.01026, 0.01027, 0.01021,
      ! 0.01018, 0.01016, 0.00977, 0.00983, 0.00968, 0.00968, 0.00944,
      ! 0.00953, 0.00970, 0.00949
    CALL CalcH("oxygen", "7782-44-7", (/ 20.40, 20.40, 20.35, 30.02, &
      30.00, 29.93, 40.00, 40.02, 40.00, 49.97, 50.00, 49.98 /),  &
      ! high-temperature data not used: 60.01, 60.04, 59.95, 69.95,
      ! 70.02, 70.03, 80.05, 79.86, 80.00
      (/ 0.03080, 0.03081, 0.03087, 0.02612, 0.02598, 0.02617, 0.02310, &
      0.02303, 0.02305, 0.02090, 0.02090, 0.02089 /)) ! O2
      ! high-temperature data not used: 0.01949, 0.01951, 0.01939,
      ! 0.01831, 0.01829, 0.01838, 0.01764, 0.01748, 0.01772

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, temp_, alpha)
      IMPLICIT NONE
      CHARACTER(LEN=*),   INTENT(IN) :: chem_
      CHARACTER(LEN=*),   INTENT(IN) :: casrn_
      REAL, DIMENSION(:), INTENT(IN) :: temp_, alpha
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      ndata = SIZE(alpha)
      ALLOCATE(Harray(ndata))
      Harray = alpha * alpha_TO_HcpSI
      CALL HTdep(temp_+CtoK, Harray, Hominus, mindHR)
      CALL MakeNote(TRIM(ref), &
        TRIM(citet())//" also contains high-temperature data. However, only " // &
        "data up to 330 K was used here to calculate the temperature dependence.")
      CALL Output(Hominus, mindHR, r2)
      DEALLOCATE(Harray)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3027

  !---------------------------------------------------------------------------

  SUBROUTINE ref3032 ! Hcp [M/atm]
    IMPLICIT NONE

    ref = "3032"
    type = "M"

    CALL CalcH("benzene",               "71-43-2", 0.17) ! C6H6 
    CALL CalcH("methylbenzene",        "108-88-3", 0.15) ! C6H5CH3 toluene
    CALL CalcH("1,4-dimethylbenzene",  "106-42-3", 0.13) ! C6H4(CH3)2 $p$-xylene
    CALL CalcH("1,3-dimethylbenzene",  "108-38-3", 0.13) ! C6H4(CH3)2 $m$-xylene
    CALL CalcH("1,2-dimethylbenzene",   "95-47-6", 0.19) ! C6H4(CH3)2 $o$-xylene
    CALL CalcH("ethenylbenzene",       "100-42-5", 0.27) ! C8H8 styrene
    CALL CalcH("propanal",             "123-38-6", 9.26) ! C2H5CHO propionaldehyde
    CALL CalcH("butanal",              "123-72-8", 6.19) ! C3H7CHO butyraldehyde
    CALL CalcH("3-methylbutanal",      "590-86-3", 2.14) ! C5H{10}O isovaleraldehyde
    CALL CalcH("pentanal",             "110-62-3", 3.98) ! C4H{9}CHO valeraldehyde
    CALL CalcH("butanone",              "78-93-3", 10.5) ! C2H5COCH3 methyl ethyl ketone; MEK
    CALL CalcH("4-methyl-2-pentanone", "108-10-1", 3.93) ! (CH3)2CHCH2COCH3 methyl isobutyl ketone; MIBK
    CALL CalcH("butyl ethanoate",      "123-86-4", 2.41) ! CH3COOC4H9 butyl acetate
    CALL CalcH("2-methyl-1-propanol",   "78-83-1", 22.2) ! C4H{10}O isobutanol

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, HLC)
      IMPLICIT NONE
      CHARACTER(LEN=*), INTENT(IN) :: chem_
      CHARACTER(LEN=*), INTENT(IN) :: casrn_
      REAL,             INTENT(IN) :: HLC
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      Hominus = Hcp_TO_HcpSI * HLC
      CALL Output(Hominus)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3032

  !---------------------------------------------------------------------------

  SUBROUTINE ref3033 ! kHcc [1]
    IMPLICIT NONE

    ref = "3033"
    type = "M"

    ! Table 1:
    CALL CalcH("phosphorus trihydride", "7803-51-2", &
      (/ 276.15, 283.15, 296.15, 301.15 /), &
      (/ 3.186,  4.271,  6.415,  7.334  /) ) ! PH3 phosphine

    ! Alternatively, Eqn. (10) could be used which describes the
    ! temperature dependence of the Henry's law constant for sea water:
    ! kHcc = a + b * T with a = -42.548 and b = 0.166.
    ! The conversion to Hcp is:
    ! Hcp = 1 / (kHcc * R * T)
    !     = 1 / ((a + b * T) * R * T)
    ! The analytical derivative is:
    ! d(ln Hcp) / d(1/T) = T * (1 + b / (b + a / T))
    ! At T0 = 298.15, this yields 2861 K.

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, temp, k)
      IMPLICIT NONE
      CHARACTER(LEN=*),   INTENT(IN) :: chem_
      CHARACTER(LEN=*),   INTENT(IN) :: casrn_
      REAL, DIMENSION(:), INTENT(IN) :: temp, k
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      CALL HTdep(temp, kHcc_TO_HcpSI(k,temp), Hominus, mindHR)
      CALL MakeNote(TRIM(ref)//"seawater", "Solubility in natural sea " // &
        "water. Measurements at different salinities were also " // &
        "performed, but only at a fixed temperature of 296.15 K.")
      CALL Output(Hominus, mindHR, r2)
    END SUBROUTINE CalcH

  END SUBROUTINE ref3033

  !---------------------------------------------------------------------------
  
  SUBROUTINE ref3034 ! kHpc [kPa*m3/mol]
    IMPLICIT NONE

    ref = "3034"

    CALL CalcH("perylene",                                  "198-55-0", 25, 0.000003,  12)
    CALL CalcH("naphthacene",                                "92-24-0", 25, 0.000004,  12)
    CALL CalcH("triphenylene",                              "217-59-4", 25, 0.00001,   12)
    CALL CalcH("benzo[a]pyrene",                             "50-32-8", 25, 0.0000465, 22)
    CALL CalcH("benzo[e]pyrene",                            "192-97-2", 17, 0.0000467, 22)
    CALL CalcH("chrysene",                                  "218-01-9", 25, 0.000065,  22)
    CALL CalcH("benzo[ghi]perylene",                        "191-24-2", 25, 0.000075,  12)
    CALL CalcH("benz[a]anthracene",                          "56-55-3", 25, 0.00058,   22)
    CALL CalcH("pyrene",                                    "129-00-0", 25, 0.00092,   22)
    CALL CalcH("fluoranthene",                              "206-44-0", 25, 0.00096,   22)
    CALL CalcH("diphenylmethane",                           "101-81-5", 25, 0.001,     12)
    CALL CalcH("acetophenone",                               "98-86-2", 20, 0.00108,   28)
    CALL CalcH("acetophenone",                               "98-86-2", 50, 0.00108,   28)
    CALL CalcH("acetophenone",                               "98-86-2", 80, 0.00108,   28)
    CALL CalcH("2-methyl-1-propanol",                        "78-83-1", 25, 0.00273,   28)
    CALL CalcH("epichlorohydrin",                           "106-89-8", 20, 0.003,     13) ! other CAS: 13403-37-7
    CALL CalcH("bis(2-chloroethyl) ether",                  "111-44-4", 20, 0.003,     13)
    CALL CalcH("phenanthrene",                               "85-01-8", 25, 0.00324,   22)
    CALL CalcH("anthracene",                                "120-12-7", 25, 0.00396,   22)
    CALL CalcH("2,2',3,3',4,4',6-heptachlorobiphenyl",    "52663-71-5", 25, 0.0054,    7)
    CALL CalcH("1-heptanol",                                "111-70-6", 25, 0.00562,   28)
    CALL CalcH("9h-fluorene",                                "86-73-7", 25, 0.00787,   22)
    CALL CalcH("2-pentanone",                               "107-87-9", 25, 0.00847,   28)
    CALL CalcH("methyloxirane",                              "75-56-9", 20, 0.0087,    13) ! other CAS: 16033-71-9
    CALL CalcH("dibenzofuran",                              "132-64-9", 25, 0.011,     12)
    CALL CalcH("acenaphthylene",                            "208-96-8", 20, 0.012,     28)
    CALL CalcH("acenaphthene",                               "83-32-9", 25, 0.01217,   22)
    CALL CalcH("1,2-diphenylethane",                        "103-29-7", 25, 0.017,     12)
    CALL CalcH("2-heptanone",                               "110-43-0", 25, 0.0171,    28)
    CALL CalcH("2-heptanone",                               "110-43-0", 90, 0.0171,    28)
    CALL CalcH("2,5-dichlorobiphenyl",                    "34883-39-1", 25, 0.0201,    7)
    CALL CalcH("decachlorobiphenyl",                       "2051-24-3", 25, 0.0208,    7)
    CALL CalcH("anisole",                                   "100-66-3", 20, 0.025,     13)
    CALL CalcH("anisole",                                   "100-66-3", 40, 0.025,     13)
    CALL CalcH("anisole",                                   "100-66-3", 81, 0.025,     13)
    CALL CalcH("1,1,2,2-tetrachloroethane",                  "79-34-5", 25, 0.026,     13)
    CALL CalcH("diphenyl ether",                            "101-84-8", 25, 0.027,     13)
    CALL CalcH("biphenyl",                                   "92-52-4", 25, 0.0280,    22)
    CALL CalcH("diiodomethane",                              "75-11-6", 30, 0.032,     13)
    CALL CalcH("2-chloronaphthalene",                        "91-58-7", 25, 0.0335,    28)
    CALL CalcH("2,2',3,3',4,4'-hexachlorobiphenyl",       "38380-07-3", 25, 0.0354,    31)
    CALL CalcH("1,5-dimethylnaphthalene",                   "571-61-9", 25, 0.036,     28)
    CALL CalcH("1-chloronaphthalene",                        "90-13-1", 25, 0.0363,    28)
    CALL CalcH("2,4,5-trichlorobiphenyl",                 "15862-07-4", 25, 0.0379,    31)
    CALL CalcH("1,2,3-trichloropropane",                     "96-18-4", 25, 0.038,     13)
    CALL CalcH("2,2',3,3',5,5',6,6'-octachlorobiphenyl",   "2136-99-4", 25, 0.0381,    7)
    CALL CalcH("1-ethylnaphthalene",                       "1127-76-0", 25, 0.039,     12)
    CALL CalcH("trans-stilbene",                            "103-30-0", 25, 0.040,     12)
    CALL CalcH("2,2',4,5,5'-pentachlorobiphenyl",         "37680-73-2", 25, 0.0421,    31)
    CALL CalcH("naphthalene",                                "91-20-3", 25, 0.043,     22)
    CALL CalcH("1-methylnaphthalene",                        "90-12-0", 25, 0.045,     22)
    CALL CalcH("tribromomethane",                            "75-25-2", 25, 0.047,     13)
    CALL CalcH("2,4,6-trichlorobiphenyl",                 "35693-92-6", 25, 0.0495,    7)
    CALL CalcH("2-methylnaphthalene",                        "91-57-6", 25, 0.051,     12)
    CALL CalcH("1,2-dibromoethane",                         "106-93-4", 50, 0.066,     13)
    CALL CalcH("2-chlorobiphenyl",                         "2051-60-7", 25, 0.0701,    7)
    CALL CalcH("2-ethylnaphthalene",                        "939-27-5", 25, 0.078,     12)
    CALL CalcH("iodobenzene",                               "591-50-4", 25, 0.078,     11)
    CALL CalcH("pentachlorobenzene",                        "608-93-5", 25, 0.085,     11)
    CALL CalcH("dibromomethane",                             "74-95-3", 20, 0.086,     13)
    CALL CalcH("diethyl ether",                              "60-29-7", 0,  0.088,     13)
    CALL CalcH("diethyl ether",                              "60-29-7", 25, 0.088,     13)
    CALL CalcH("diethyl ether",                              "60-29-7", 38, 0.088,     13)
    CALL CalcH("diethyl ether",                              "60-29-7", 82, 0.088,     13)
    CALL CalcH("1,1,2-trichloroethane",                      "79-00-5", 25, 0.092,     13)
    CALL CalcH("1-chloro-2-methylpropene",                  "513-37-1", 25, 0.12,      5)
    CALL CalcH("1,2,4,5-tetrachlorobenzene",                 "95-94-3", 25, 0.122,     11)
    CALL CalcH("hexachlorobenzene",                         "118-74-1", 25, 0.131,     11)
    CALL CalcH("1,2-dichloroethane",                        "107-06-2", 25, 0.14,      13)
    CALL CalcH("1,2,3,4-tetrachlorobenzene",                "634-66-2", 25, 0.144,     11)
    CALL CalcH("trans-1,3-dichloropropene",               "10061-02-6", 20, 0.18,      5)
    CALL CalcH("bromochloromethane",                         "74-97-5", 25, 0.18,      13)
    CALL CalcH("cis-1,3-dichloropropene",                 "10061-01-5", 20, 0.24,      5)
    CALL CalcH("1,1,1,2-tetrachloroethane",                 "630-20-6", 25, 0.24,      13)
    CALL CalcH("1,2,3-trichlorobenzene",                     "87-61-6", 25, 0.242,     11)
    CALL CalcH("p-dichlorobenzene",                         "106-46-7", 25, 0.244,     28)
    CALL CalcH("bromobenzene",                              "108-86-1", 25, 0.250,     28)
    CALL CalcH("pentachloroethane",                          "76-01-7", 25, 0.25,      13)
    CALL CalcH("dipropyl ether",                            "111-43-3", 0,  0.26,      13)
    CALL CalcH("dipropyl ether",                            "111-43-3", 25, 0.26,      13)
    CALL CalcH("diisopropyl ether",                         "108-20-3", 20, 0.26,      13)
    CALL CalcH("1,2,4-trichlorobenzene",                    "120-82-1", 25, 0.277,     11)
    CALL CalcH("styrene",                                   "100-42-5", 25, 0.286,     22)
    CALL CalcH("1,2-dichloropropane, (+-)-",                 "78-87-5", 25, 0.29,      13) ! other CAS: 26198-63-0
    CALL CalcH("dichloromethane",                            "75-09-2", 25, 0.30,      13)
    CALL CalcH("styrene",                                   "100-42-5", 50, 0.30,      13)
    CALL CalcH("1,2,3-trimethylbenzene",                    "526-73-8", 25, 0.343,     22)
    CALL CalcH("2,3-dichloropropene",                        "78-88-6", 25, 0.36,      5)
    CALL CalcH("m-dichlorobenzene",                         "541-73-1", 25, 0.376,     11)
    CALL CalcH("trichloromethane",                           "67-66-3", 25, 0.43,      13)
    CALL CalcH("trichloromethane",                           "67-66-3", 59, 0.43,      13)
    CALL CalcH("cis-1,2-dichloroethene",                    "156-59-2", 25, 0.46,      13)
    CALL CalcH("1,3,5-cycloheptatriene",                    "544-25-2", 25, 0.47,      13)
    CALL CalcH("dibutyl ether",                             "142-96-1", 0,  0.48,      13)
    CALL CalcH("dibutyl ether",                             "142-96-1", 20, 0.48,      13)
    CALL CalcH("4-ethyltoluene",                            "622-96-8", 25, 0.500,     13)
    CALL CalcH("iodoethane",                                 "75-03-6", 25, 0.52,      13)
    CALL CalcH("2-ethyltoluene",                            "611-14-3", 25, 0.529,     13)
    CALL CalcH("furan",                                     "110-00-9", 25, 0.54,      13)
    CALL CalcH("iodomethane",                                "74-88-4", 20, 0.54,      13)
    CALL CalcH("o-xylene",                                   "95-47-6", 25, 0.551,     22)
    CALL CalcH("1,2,4-trimethylbenzene",                     "95-63-6", 25, 0.569,     22)
    CALL CalcH("1,2,3,5-tetrachlorobenzene",                "634-90-2", 25, 0.59,      11)
    CALL CalcH("1,1-dichloroethane",                         "75-34-3", 25, 0.63,      13)
    CALL CalcH("bromomethane",                               "74-83-9", 20, 0.63,      13)
    CALL CalcH("toluene",                                   "108-88-3", 25, 0.660,     22)
    CALL CalcH("2-methyltetrahydrofuran",                    "96-47-9", 19, 0.67,      13)
    CALL CalcH("p-xylene",                                  "106-42-3", 25, 0.690,     22)
    CALL CalcH("fluorobenzene",                             "462-06-6", 19, 0.70,      11)
    CALL CalcH("fluorobenzene",                             "462-06-6", 80, 0.70,      11)
    CALL CalcH("m-xylene",                                  "108-38-3", 25, 0.730,     22)
    CALL CalcH("1,3,5-trimethylbenzene",                    "108-67-8", 25, 0.781,     22)
    CALL CalcH("1-isopropyl-4-methylbenzene",                "99-87-6", 25, 0.80,      5)
    CALL CalcH("2,2',4,4',6,6'-hexachlorobiphenyl",       "33979-03-2", 25, 0.818,     7)
    CALL CalcH("ethylbenzene",                              "100-41-4", 25, 0.843,     22)
    CALL CalcH("hexachloroethane",                           "67-72-1", 25, 0.85,      13)
    CALL CalcH("1-iodopropane",                             "107-08-4", 20, 0.93,      13)
    CALL CalcH("trans-1,2-dichloroethene",                  "156-60-5", 25, 0.96,      13)
    CALL CalcH("chloromethane",                              "74-87-3", 25, 0.98,      13)
    CALL CalcH("chloroethane",                               "75-00-3", 25, 1.02,      13)
    CALL CalcH("1,4-cyclohexadiene",                        "628-41-1", 25, 1.03,      13)
    CALL CalcH("trichloroethene",                            "79-01-6", 25, 1.03,      13)
    CALL CalcH("propylbenzene",                             "103-65-1", 25, 1.041,     22)
    CALL CalcH("1,3,5-trichlorobenzene",                    "108-70-3", 25, 1.1,       11)
    CALL CalcH("3-chloropropene",                           "107-05-1", 25, 1.10,      5)
    CALL CalcH("propyne",                                    "74-99-7", 25, 1.11,      5)
    CALL CalcH("1-bromobutane",                             "109-65-9", 25, 1.2,       13)
    CALL CalcH("bromoethane",                                "74-96-4", 25, 1.23,      13)
    CALL CalcH("2-bromopropane",                             "75-26-3", 20, 1.27,      13)
    CALL CalcH("tert-butylbenzene",                          "98-06-6", 25, 1.28,      11)
    CALL CalcH("butylbenzene",                              "104-51-8", 25, 1.33,      22)
    CALL CalcH("1-chloropropane",                           "540-54-5", 25, 1.41,      13)
    CALL CalcH("isopropylbenzene",                           "98-82-8", 25, 1.466,     22)
    CALL CalcH("1-chlorobutane",                            "109-69-3", 25, 1.54,      13)
    CALL CalcH("pentylbenzene",                             "538-68-1", 25, 1.69,      11)
    CALL CalcH("tetrachloroethene",                         "127-18-4", 20, 1.73,      13)
    CALL CalcH("1,1,1-trichloroethane",                      "71-55-6", 25, 1.76,      13)
    CALL CalcH("1-iodobutane",                              "542-69-8", 17, 1.87,      13)
    CALL CalcH("sec-butylbenzene, (+-)-",                   "135-98-8", 25, 1.89,      11) ! other CAS: 36383-15-0
    CALL CalcH("1-butyne",                                  "107-00-6", 25, 1.91,      5)
    CALL CalcH("1-chloropentane",                           "543-59-9", 25, 2.37,      13)
    CALL CalcH("1-pentyne",                                 "627-19-0", 25, 2.5,       5)
    CALL CalcH("1,2,4,5-tetramethylbenzene",                 "95-93-2", 25, 2.55,      11)
    CALL CalcH("1,1-dichloroethene",                         "75-35-4", 25, 2.62,      13)
    CALL CalcH("chloroethene",                               "75-01-4", 25, 2.68,      13)
    CALL CalcH("tetrachloromethane",                         "56-23-5", 25, 2.99,      13)
    CALL CalcH("tetrachloromethane",                         "56-23-5", 75, 2.99,      13)
    CALL CalcH("chlorodifluoromethane",                      "75-45-6", 25, 3.0,       13)
    CALL CalcH("trans-decahydronaphthalene",                "493-02-7", 25, 3.,        13) ! ref 13 says: 3.644
    CALL CalcH("isobutylbenzene",                           "538-93-2", 25, 3.32,      11)
    CALL CalcH("1-bromopropane",                            "106-94-5", 25, 3.8,       13)
    CALL CalcH("1-hexyne",                                  "693-02-7", 25, 4.14,      13)
    CALL CalcH("1-heptyne",                                 "628-71-7", 25, 4.47,      13)
    CALL CalcH("cyclohexene",                               "110-83-8", 25, 4.57,      13)
    CALL CalcH("cycloheptene",                              "628-92-2", 25, 4.9,       13)
    CALL CalcH("cyclopentene",                              "142-29-0", 25, 6.56,      13)
    CALL CalcH("chlorotrifluoromethane",                     "75-72-9", 25, 6.9,       13)
    CALL CalcH("2-methyl-1,3-butadiene",                     "78-79-5", 25, 7.78,      5)
    CALL CalcH("1-octyne",                                  "629-05-0", 25, 7.87,      13)
    CALL CalcH("cycloheptane",                              "291-64-5", 25, 9.59,      13)
    CALL CalcH("trichlorofluoromethane",                     "75-69-4", 20, 10.2,      13)
    CALL CalcH("cyclooctane",                               "292-64-8", 25, 10.7,      13)
    CALL CalcH("1,4-pentadiene",                            "591-93-5", 25, 12.,       5)
    CALL CalcH("aniline",                                    "62-53-3", 25, 14.,       15)
    CALL CalcH("cyclopentane",                              "287-92-3", 25, 19.1,      13)
    CALL CalcH("cyclohexane",                               "110-82-7", 25, 19.4,      13)
    CALL CalcH("1,3-butadiene",                             "106-99-0", 25, 20.7,      13)
    CALL CalcH("propene",                                   "115-07-1", 25, 21.3,      5)
    CALL CalcH("isobutene",                                 "115-11-7", 25, 21.6,      13)
    CALL CalcH("ethylene",                                   "74-85-1", 25, 21.7,      5)
    CALL CalcH("cis-2-pentene",                             "627-20-3", 25, 22.8,      5)
    CALL CalcH("1-butene",                                  "106-98-9", 25, 25.6,      13)
    CALL CalcH("2-methyl-1-pentene",                        "763-29-1", 25, 28.1,      5)
    CALL CalcH("1,1,2-trichloro-1,2,2-trifluoroethane",      "76-13-1", 25, 32.,       13)
    CALL CalcH("cis-1,2-dimethylcyclohexane",              "2207-01-4", 25, 36.,       5)
    CALL CalcH("methylcyclopentane",                         "96-37-7", 25, 36.7,      5)
    CALL CalcH("1-heptene",                                 "592-76-7", 25, 40.3,      13)
    CALL CalcH("1-pentene",                                 "109-67-1", 25, 40.3,      5)
    CALL CalcH("dichlorodifluoromethane",                    "75-71-8", 20, 41.,       13)
    CALL CalcH("1-hexene",                                  "592-41-6", 25, 41.8,      5)
    CALL CalcH("trans-2-heptene",                         "14686-13-6", 25, 42.2,      13)
    CALL CalcH("methylcyclohexane",                         "108-87-2", 26, 43.3,      13)
    CALL CalcH("ethane",                                     "74-84-0", 25, 50.6,      5)
    CALL CalcH("3-methyl-1-butene",                         "563-45-1", 25, 54.7,      5)
    CALL CalcH("4-methyl-1-pentene",                        "691-37-2", 25, 63.2,      5)
    CALL CalcH("methane",                                    "74-82-8", 25, 67.4,      5)
    CALL CalcH("propane",                                    "74-98-6", 25, 71.6,      5)
    CALL CalcH("trans-1,2-dimethylcyclohexane",            "6876-23-9", 30, 88.2,      5)
    CALL CalcH("propylcyclopentane",                       "2040-96-2", 25, 90.2,      5)
    CALL CalcH("butane",                                    "106-97-8", 25, 95.9,      5)
    CALL CalcH("1-octene",                                  "111-66-0", 25, 96.3,      13)
    CALL CalcH("1,1,3-trimethylcyclohexane",               "3073-66-3", 25, 105.,      13)
    CALL CalcH("isobutane",                                  "75-28-5", 25, 120.,      5)
    CALL CalcH("1,2-dichloro-1,1,2,2-tetrafluoroethane",     "76-14-2", 25, 127.,      13)
    CALL CalcH("pentane",                                   "109-66-0", 25, 128.,      13)
    CALL CalcH("2,3-dimethylbutane",                         "79-29-8", 25, 144.,      13)
    CALL CalcH("1,1,3-trimethylcyclopentane",              "4516-69-2", 25, 159.,      5)
    CALL CalcH("3-methylpentane",                            "96-14-0", 25, 170.,      13)
    CALL CalcH("2,3-dimethylpentane",                       "565-59-3", 25, 175.,      5)
    CALL CalcH("2-methylpentane",                           "107-83-5", 25, 176.,      13)
    CALL CalcH("hexane",                                    "110-54-3", 75, 183.,      13)
    CALL CalcH("pentylcyclopentane",                       "3741-00-2", 25, 185.,      5)
    CALL CalcH("3,3-dimethylpentane",                       "562-49-2", 25, 186.,      5)
    CALL CalcH("2,2-dimethylbutane",                         "75-83-2", 25, 199.,      13)
    CALL CalcH("2,3,4-trimethylpentane",                    "565-75-3", 25, 206.,      13)
    CALL CalcH("heptane",                                   "142-82-5", 50, 209.,      13)
    CALL CalcH("neopentane",                                "463-82-1", 25, 220.,      13)
    CALL CalcH("2,2,5-trimethylhexane",                    "3522-94-9", 25, 246.,      13)
    CALL CalcH("3-methylhexane",                            "589-34-4", 25, 249.,      13) ! other CAS: 78918-91-9 for (R)-enantiomer
    CALL CalcH("chloropentafluoroethane",                    "76-15-3", 25, 260.,      13)
    CALL CalcH("2,2,4-trimethylpentane",                    "540-84-1", 25, 307.,      13)
    CALL CalcH("octane",                                    "111-65-9", 25, 311.,      13)
    CALL CalcH("2,2-dimethylpentane",                       "590-35-2", 25, 318.,      5)
    CALL CalcH("2,4-dimethylpentane",                       "108-08-7", 25, 323.,      13)
    CALL CalcH("nonane",                                    "111-84-2", 25, 333.,      13)
    CALL CalcH("2-methylhexane",                            "591-76-4", 25, 346.,      5)
    CALL CalcH("3-methylheptane",                           "589-81-1", 25, 376.,      5)
    CALL CalcH("isopentane",                                 "78-78-4", 25, 479.,      13)
    CALL CalcH("decane",                                    "124-18-5", 0,  479.,      13)
    CALL CalcH("dodecane",                                  "112-40-3", 25, 750.,      5)
    CALL CalcH("4-methyloctane",                           "2216-34-4", 25, 1000.,     5)

    chem = "1-chloro-2-methylpropene" ; casrn = "513-37-1"
    type = "?"
    CALL MakeNote("CRCwrong1", &
      TRIM(citet())//" refer to \citet{479} but that "// &
      "article lists this value for 1-chloro-2-methylpropane "// &
      "(the saturated compound), not for 1-chloro-2-methylpropene.")
    CALL Output(DUMMY)

    chem = "trans-1,2-dimethylcyclohexane" ; casrn = "6876-23-9"
    type = "?"
    CALL MakeNote("CRCwrong2", &
      TRIM(citet())//" refer to \citet{479} but that "// &
      "article lists this value for 1,4-dimethylcyclohexane, "// &
      "not for 1,2-dimethylcyclohexane.")
    CALL Output(DUMMY)

    chem = "1-bromobutane" ; casrn = "109-65-9" ! C4H9Br 
    type = "?"
    CALL MakeNote("CRCwrong3", &
      TRIM(citet())//" refer to \citet{635} "// &
      "as the source but this value cannot be found there.")
    CALL Output(kHpcSI_TIMES_HcpSI/(1.2*1.E3))

  CONTAINS

    SUBROUTINE CalcH (chem_, casrn_, temp, kHpc, refnumber)
      IMPLICIT NONE
      CHARACTER(LEN=*), INTENT(IN) :: chem_
      CHARACTER(LEN=*), INTENT(IN) :: casrn_
      INTEGER,          INTENT(IN) :: temp
      REAL,             INTENT(IN) :: kHpc
      INTEGER,          INTENT(IN) :: refnumber
      LOGICAL :: l_output
      chem  = chem_  ! make value global, so Output will find it
      casrn = casrn_ ! make value global, so Output will find it
      ! only show output for debugging or if original paper is not yet included:
      l_output = .TRUE.
      SELECT CASE(refnumber)
      CASE ( 5)  ; CALL SettypeX("479")      ; l_output = .FALSE.
      CASE ( 7)  ; CALL SettypeX("2302")     ; l_output = .FALSE.
      CASE (11)  ; CALL SettypeX("633")      ; l_output = .FALSE.
      CASE (12)  ; CALL SettypeX("634")      ! l_output = .FALSE.
      CASE (13)  ; CALL SettypeX("635")      ; l_output = .FALSE.
      CASE (15)  ; CALL SettypeX("howard89") ! l_output = .FALSE.
      CASE (22)  ; CALL SettypeX("2338")     ; l_output = .FALSE.
      CASE (28)  ; CALL SettypeX("2339")     ; l_output = .FALSE.
      CASE (31)  ; CALL SettypeX("2340")     ; l_output = .FALSE.
      CASE DEFAULT
        print *, "refnumber error in ref3034"
      END SELECT
      IF (l_output) THEN
        SELECT CASE(temp)
        CASE(0)  ; CALL MakeNoteOtherTemp("273")
        CASE(17) ; CALL MakeNoteOtherTemp("290")
        CASE(19) ; CALL MakeNoteOtherTemp("292")
        CASE(20) ; CALL MakeNoteOtherTemp("293")
        CASE(26) ; CALL MakeNoteOtherTemp("299")
        CASE(30) ; CALL MakeNoteOtherTemp("303")
        CASE(38) ; CALL MakeNoteOtherTemp("311")
        CASE(40) ; CALL MakeNoteOtherTemp("313")
        CASE(50) ; CALL MakeNoteOtherTemp("323")
        CASE(59) ; CALL MakeNoteOtherTemp("332")
        CASE(75) ; CALL MakeNoteOtherTemp("348")
        CASE(80) ; CALL MakeNoteOtherTemp("353")
        CASE(81) ; CALL MakeNoteOtherTemp("354")
        CASE(82) ; CALL MakeNoteOtherTemp("355")
        CASE(90) ; CALL MakeNoteOtherTemp("363")
        CASE DEFAULT
          IF (temp/=25) print *, "temp error in ref3034"
        END SELECT
        Hominus = kHpcSI_TIMES_HcpSI/(kHpc*1.E3)
        CALL Output(Hominus)
      ELSE
        seenote = "" ! reset so that next CALL Output won't use it
        type    = "" ! reset to invalid value that will be overwritten
      ENDIF
    END SUBROUTINE CalcH

  END SUBROUTINE ref3034

  !---------------------------------------------------------------------------

END MODULE Henry_ref3500

!*****************************************************************************
!                                  end of file
!*****************************************************************************
